function love.run ()
	-- these don't change, so we can make them local for faster access
	local audio, graphics = love.audio, love.graphics
	local event, timer = love.event, love.timer

	-- Prepare stuff
	if love.load then love.load(arg) end

    local dt = 0

	if timer then
		-- Set a reasonable FPS limit
		local FPS = 60
		dt = 1/FPS
	end

	-- Main loop
	while true do
		-- Update the timer
		if timer then timer.step() end

		-- Process events
		if event then
			for e, a, b, c in event.poll() do
				if e == "q" then
					if not love.quit or not love.quit() then
						if audio then audio.stop() end
					end
					return
				end
				love.handlers[e](a, b, c)
			end
		end
		
		-- Do the game mechanic
		if love.update then love.update(dt) end

		-- Draw the graphics
		if graphics then
			graphics.clear()
			if love.draw then love.draw() end
		end

		-- Wait for the end of this frame
		if timer then
			timer.step()
			local time_work = timer.getDelta()
			if time_work < dt then
				timer.sleep((dt - time_work) * 1000)
			end
		end

		-- Show the frame
		if graphics then
			graphics.present()
		end
	end
end


-- vim: ts=4 sw=4 si
