require 'love-run'
require 'coordinates'

local color1 =		{ 0x34, 0x65, 0xa4, 0xff }
local color2 =		{ 0xed, 0xd4, 0x00, 0xff }

local ship_verts = {
	0, -64,
	12, -48,
	16, -32,
	16, 16,
	12, 64,
	-12, 64,
	-16, 16,
	-16, -32,
	-12, -48,
}

local bw, bl = 1, 16
local tw = 4
local turret_verts = {
	bw, -tw - bl,
	bw, -tw,
	tw, -tw,
	tw, tw,
	-tw, tw,
	-tw, -tw,
	-bw, -tw,
	-bw, -tw - bl,
}

local function global_verts (refx, refy, refr, ...)
	local function convert (vertx, verty, ...)
		if vertx and verty then
			local x, y = local2global(vertx, verty, 0, refx, refy, refr)
			return x, y, convert(...)
		end
	end
	return convert(...)
end


function love.load(args)
	love.graphics.setBackgroundColor(0, 0, 0)
	ship = {
		x = 400,
		y = 300,
		a = 0
	}
	turret = {
		x = 0,
		y = -32,
		a = 0
	}
end

local speed = 64
local fullturn = 2 * math.pi
local ship_turn_speed= fullturn/4
local turret_turn_speed = fullturn/2

local keymap = {
	['w'] = function (dt)
		ship.x, ship.y, ship.a = local2global(0, -speed*dt, 0, ship.x, ship.y, ship.a)
	end,
	['a'] = function (dt)
		ship.a = ship.a - ship_turn_speed*dt
	end,
	['d'] = function (dt)
		ship.a = ship.a + ship_turn_speed*dt
	end,
	['q'] = function (dt)
		turret.a = turret.a - turret_turn_speed*dt
	end,
	['e'] = function (dt)
		turret.a = turret.a + turret_turn_speed*dt
	end,
}

function love.update (dt)
	for k, v in pairs(keymap) do
		if love.keyboard.isDown(k) then v(dt) end
	end
end

function love.draw ()
	local ship_v = { global_verts(ship.x, ship.y, ship.a ,unpack(ship_verts)) }
	local turret_v = { global_verts(turret.x, turret.y, turret.a, unpack(turret_verts)) }
	turret_v = { global_verts(ship.x, ship.y, ship.a, unpack(turret_v)) }

	love.graphics.setColor(unpack(color1))
	love.graphics.polygon('fill', unpack(ship_v))
	love.graphics.polygon('line', unpack(ship_v))

	love.graphics.setColor(unpack(color2))
	love.graphics.polygon('line', unpack(turret_v))
end

-- vim: ts=4 sw=4 ai
